<?php

namespace Drupal\meetmy_bot_clone\Form;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Config\TypedConfigManagerInterface;
use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\meetmy_bot_clone\Service\ConfigManager;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Configuration form for MeetMy.bot Clone settings.
 */
class SettingsForm extends ConfigFormBase {

  /**
   * The config manager service.
   *
   * @var \Drupal\meetmy_bot_clone\Service\ConfigManager
   */
  protected $configManager;

  /**
   * Constructs a SettingsForm object.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   The config factory.
   * @param \Drupal\Core\Config\TypedConfigManagerInterface $typed_config_manager
   *   The typed config manager.
   * @param \Drupal\meetmy_bot_clone\Service\ConfigManager $config_manager
   *   The config manager service.
   */
  public function __construct(ConfigFactoryInterface $config_factory, TypedConfigManagerInterface $typed_config_manager, ConfigManager $config_manager) {
    parent::__construct($config_factory, $typed_config_manager);
    $this->configManager = $config_manager;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('config.factory'),
      $container->get('config.typed'),
      $container->get('meetmy_bot_clone.config_manager')
    );
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [ConfigManager::CONFIG_NAME];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'meetmy_bot_clone_settings_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->configManager->getConfig();

    $form['general'] = [
      '#type' => 'fieldset',
      '#title' => $this->t('General Settings'),
      '#collapsible' => FALSE,
    ];

    $form['general']['title'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Title'),
      '#description' => $this->t('The title displayed for the bot interface.'),
      '#default_value' => $config->get('title'),
      '#required' => TRUE,
      '#maxlength' => 255,
    ];

    $form['general']['bot_url'] = [
      '#type' => 'url',
      '#title' => $this->t('Bot URL'),
      '#description' => $this->t('The complete URL to the MeetMy.bot Clone interface.'),
      '#default_value' => $config->get('bot_url'),
      '#required' => TRUE,
      '#maxlength' => 2048,
    ];

    $form['display'] = [
      '#type' => 'fieldset',
      '#title' => $this->t('Display Settings'),
      '#collapsible' => FALSE,
    ];

    $form['display']['display_mode'] = [
      '#type' => 'radios',
      '#title' => $this->t('Display Mode'),
      '#description' => $this->t('Choose how the bot interface should be displayed.'),
      '#options' => [
        'modal' => $this->t('Modal Window (Popup) - FULLSCREEN'),
        'inline' => $this->t('Inline (Embedded in region)'),
      ],
      '#default_value' => $config->get('display_mode') ?: 'modal',
      '#required' => TRUE,
    ];

    $form['display']['modal_fullscreen'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Fullscreen Modal'),
      '#description' => $this->t('Make modal window fullscreen (100% width and height). NOTE: Modal is now FULLSCREEN BY DEFAULT.'),
      '#default_value' => $config->get('modal_fullscreen') ?: FALSE,
      '#disabled' => TRUE,
      '#states' => [
        'visible' => [
          ':input[name="display_mode"]' => ['value' => 'modal'],
        ],
      ],
    ];

    $form['display']['window_size'] = [
      '#type' => 'fieldset',
      '#title' => $this->t('Window Size'),
      '#description' => $this->t('Set the dimensions for the bot interface. You can use pixels (e.g., 400) or percentages (e.g., 100%). NOTE: For modal mode, these are used only for inline fallback.'),
    ];

    $form['display']['window_size']['width_value'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Width'),
      '#description' => $this->t('Enter width value (numbers only).'),
      '#default_value' => $config->get('width_value') ?: '400',
      '#required' => TRUE,
      '#size' => 10,
    ];

    $form['display']['window_size']['width_unit'] = [
      '#type' => 'select',
      '#title' => $this->t('Width Unit'),
      '#options' => [
        'px' => $this->t('Pixels (px)'),
        '%' => $this->t('Percentage (%)'),
        'vw' => $this->t('Viewport Width (vw)'),
      ],
      '#default_value' => $config->get('width_unit') ?: 'px',
      '#required' => TRUE,
    ];

    $form['display']['window_size']['height_value'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Height'),
      '#description' => $this->t('Enter height value (numbers only).'),
      '#default_value' => $config->get('height_value') ?: '600',
      '#required' => TRUE,
      '#size' => 10,
    ];

    $form['display']['window_size']['height_unit'] = [
      '#type' => 'select',
      '#title' => $this->t('Height Unit'),
      '#options' => [
        'px' => $this->t('Pixels (px)'),
        '%' => $this->t('Percentage (%)'),
        'vh' => $this->t('Viewport Height (vh)'),
      ],
      '#default_value' => $config->get('height_unit') ?: 'px',
      '#required' => TRUE,
    ];

    $form['media'] = [
      '#type' => 'fieldset',
      '#title' => $this->t('Media Settings'),
      '#collapsible' => FALSE,
    ];

    $form['media']['preview_video_url'] = [
      '#type' => 'url',
      '#title' => $this->t('Preview Video URL'),
      '#description' => $this->t('URL to the preview video that plays before the bot interface is activated. Leave empty to disable preview.'),
      '#default_value' => $config->get('preview_video_url'),
      '#maxlength' => 2048,
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    parent::validateForm($form, $form_state);

    $bot_url = $form_state->getValue('bot_url');
    if (!empty($bot_url) && !filter_var($bot_url, FILTER_VALIDATE_URL)) {
      $form_state->setErrorByName('bot_url', $this->t('Please enter a valid URL for the bot.'));
    }

    $preview_video_url = $form_state->getValue('preview_video_url');
    if (!empty($preview_video_url) && !filter_var($preview_video_url, FILTER_VALIDATE_URL)) {
      $form_state->setErrorByName('preview_video_url', $this->t('Please enter a valid URL for the preview video.'));
    }

    $width_value = $form_state->getValue('width_value');
    $height_value = $form_state->getValue('height_value');

    if (!is_numeric($width_value) || $width_value <= 0) {
      $form_state->setErrorByName('width_value', $this->t('Width value must be a positive number.'));
    }

    if (!is_numeric($height_value) || $height_value <= 0) {
      $form_state->setErrorByName('height_value', $this->t('Height value must be a positive number.'));
    }

    $width_unit = $form_state->getValue('width_unit');
    $height_unit = $form_state->getValue('height_unit');

    if ($width_unit === 'px' && ($width_value < 200 || $width_value > 2000)) {
      $form_state->setErrorByName('width_value', $this->t('Width in pixels must be between 200 and 2000.'));
    }

    if ($height_unit === 'px' && ($height_value < 300 || $height_value > 1200)) {
      $form_state->setErrorByName('height_value', $this->t('Height in pixels must be between 300 and 1200.'));
    }

    if ($width_unit === '%' && ($width_value < 10 || $width_value > 100)) {
      $form_state->setErrorByName('width_value', $this->t('Width percentage must be between 10 and 100.'));
    }

    if ($height_unit === '%' && ($height_value < 10 || $height_value > 100)) {
      $form_state->setErrorByName('height_value', $this->t('Height percentage must be between 10 and 100.'));
    }
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $config = $this->configManager->getEditableConfig();

    $config
      ->set('title', $form_state->getValue('title'))
      ->set('bot_url', $form_state->getValue('bot_url'))
      ->set('display_mode', $form_state->getValue('display_mode'))
      ->set('modal_fullscreen', TRUE)
      ->set('width_value', $form_state->getValue('width_value'))
      ->set('width_unit', $form_state->getValue('width_unit'))
      ->set('height_value', $form_state->getValue('height_value'))
      ->set('height_unit', $form_state->getValue('height_unit'))
      ->set('preview_video_url', $form_state->getValue('preview_video_url'))
      ->save();

    parent::submitForm($form, $form_state);

    $this->messenger()->addMessage($this->t('MeetMy.bot Clone settings have been saved. Modal windows are now FULLSCREEN by default!'));
  }

}
