<?php

namespace Drupal\meetmy_bot_clone\Plugin\Block;

use Drupal\Core\Block\BlockBase;
use Drupal\Core\Block\BlockPluginInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\meetmy_bot_clone\Service\ConfigManager;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides a MeetMy.bot Clone block.
 *
 * @Block(
 *   id = "meetmy_bot_clone_block",
 *   admin_label = @Translation("MeetMy.bot Clone"),
 *   category = @Translation("MeetMy.bot Clone")
 * )
 */
class BotBlock extends BlockBase implements BlockPluginInterface, ContainerFactoryPluginInterface {

  /**
   * The config manager service.
   *
   * @var \Drupal\meetmy_bot_clone\Service\ConfigManager
   */
  protected $configManager;

  /**
   * Constructs a BotBlock object.
   *
   * @param array $configuration
   *   The plugin configuration.
   * @param string $plugin_id
   *   The plugin ID.
   * @param mixed $plugin_definition
   *   The plugin definition.
   * @param \Drupal\meetmy_bot_clone\Service\ConfigManager $config_manager
   *   The config manager service.
   */
  public function __construct(array $configuration, $plugin_id, $plugin_definition, ConfigManager $config_manager) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->configManager = $config_manager;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('meetmy_bot_clone.config_manager')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration() {
    return [
      'override_title' => FALSE,
      'custom_title' => '',
      'override_dimensions' => FALSE,
      'custom_width' => 400,
      'custom_height' => 600,
      'show_preview' => TRUE,
    ] + parent::defaultConfiguration();
  }

  /**
   * {@inheritdoc}
   */
  public function blockForm($form, FormStateInterface $form_state) {
    $form = parent::blockForm($form, $form_state);
    $config = $this->getConfiguration();

    $form['override_title'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Override global title'),
      '#description' => $this->t('Check this to use a custom title for this block instance.'),
      '#default_value' => $config['override_title'],
    ];

    $form['custom_title'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Custom title'),
      '#description' => $this->t('Enter a custom title for this block.'),
      '#default_value' => $config['custom_title'],
      '#maxlength' => 255,
      '#states' => [
        'visible' => [
          ':input[name="settings[override_title]"]' => ['checked' => TRUE],
        ],
        'required' => [
          ':input[name="settings[override_title]"]' => ['checked' => TRUE],
        ],
      ],
    ];

    $form['override_dimensions'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Override global dimensions'),
      '#description' => $this->t('Check this to use custom dimensions for this block instance.'),
      '#default_value' => $config['override_dimensions'],
    ];

    $form['dimensions'] = [
      '#type' => 'fieldset',
      '#title' => $this->t('Custom Dimensions'),
      '#states' => [
        'visible' => [
          ':input[name="settings[override_dimensions]"]' => ['checked' => TRUE],
        ],
      ],
    ];

    $form['dimensions']['custom_width'] = [
      '#type' => 'number',
      '#title' => $this->t('Width (pixels)'),
      '#default_value' => $config['custom_width'],
      '#min' => 200,
      '#max' => 2000,
      '#step' => 10,
      '#states' => [
        'required' => [
          ':input[name="settings[override_dimensions]"]' => ['checked' => TRUE],
        ],
      ],
    ];

    $form['dimensions']['custom_height'] = [
      '#type' => 'number',
      '#title' => $this->t('Height (pixels)'),
      '#default_value' => $config['custom_height'],
      '#min' => 300,
      '#max' => 1200,
      '#step' => 10,
      '#states' => [
        'required' => [
          ':input[name="settings[override_dimensions]"]' => ['checked' => TRUE],
        ],
      ],
    ];

    $form['show_preview'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Show preview video'),
      '#description' => $this->t('Uncheck this to disable the preview video for this block (if configured globally).'),
      '#default_value' => $config['show_preview'],
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function blockValidate($form, FormStateInterface $form_state) {
    if ($form_state->getValue('override_title') && empty($form_state->getValue('custom_title'))) {
      $form_state->setErrorByName('custom_title', $this->t('Custom title is required when override is enabled.'));
    }

    if ($form_state->getValue('override_dimensions')) {
      $width = $form_state->getValue(['dimensions', 'custom_width']);
      $height = $form_state->getValue(['dimensions', 'custom_height']);

      if ($width < 200 || $width > 2000) {
        $form_state->setErrorByName('dimensions][custom_width', $this->t('Width must be between 200 and 2000 pixels.'));
      }

      if ($height < 300 || $height > 1200) {
        $form_state->setErrorByName('dimensions][custom_height', $this->t('Height must be between 300 and 1200 pixels.'));
      }
    }
  }

  /**
   * {@inheritdoc}
   */
  public function blockSubmit($form, FormStateInterface $form_state) {
    $this->configuration['override_title'] = $form_state->getValue('override_title');
    $this->configuration['custom_title'] = $form_state->getValue('custom_title');
    $this->configuration['override_dimensions'] = $form_state->getValue('override_dimensions');
    $this->configuration['custom_width'] = (int) $form_state->getValue(['dimensions', 'custom_width']);
    $this->configuration['custom_height'] = (int) $form_state->getValue(['dimensions', 'custom_height']);
    $this->configuration['show_preview'] = $form_state->getValue('show_preview');
  }

  /**
   * {@inheritdoc}
   */
  public function build() {
    if (!$this->configManager->isConfigured()) {
      return [
        '#markup' => $this->t('MeetMy.bot Clone is not configured. Please <a href="@url">configure it</a> first.', [
          '@url' => '/admin/config/services/meetmy-bot-clone',
        ]),
      ];
    }

    $config = $this->getConfiguration();
    $global_config = $this->configManager->getAllConfig();

    // Fix: Use correct keys from ConfigManager
    $title = $config['override_title'] ? $config['custom_title'] : $global_config['title'];
    $width = $config['override_dimensions'] ? $config['custom_width'] . 'px' : $global_config['width'];
    $height = $config['override_dimensions'] ? $config['custom_height'] . 'px' : $global_config['height'];
    $show_preview = $config['show_preview'] && !empty($global_config['preview_video_url']);

    $build = [
      '#theme' => 'meetmy_bot_clone_block',
      '#title' => $title,
      '#bot_url' => $global_config['bot_url'],
      '#width' => $width,
      '#height' => $height,
      '#display_mode' => $global_config['display_mode'],
      '#modal_fullscreen' => $global_config['modal_fullscreen'],
      '#preview_video_url' => $show_preview ? $global_config['preview_video_url'] : '',
      '#attached' => [
        'library' => ['meetmy_bot_clone/bot_interface'],
        'drupalSettings' => [
          'meetmyBotClone' => [
            'botUrl' => $global_config['bot_url'],
            'width' => $width,
            'height' => $height,
            'displayMode' => $global_config['display_mode'],
            'modalFullscreen' => $global_config['modal_fullscreen'],
            'previewVideoUrl' => $show_preview ? $global_config['preview_video_url'] : '',
          ],
        ],
      ],
    ];

    return $build;
  }

}