<?php

namespace Drupal\meetmy_bot_clone\Service;

use Drupal\Core\Config\ConfigFactoryInterface;

/**
 * Service for managing MeetMy.bot Clone configuration.
 */
class ConfigManager {

  const CONFIG_NAME = 'meetmy_bot_clone.settings';

  /**
   * The config factory.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected $configFactory;

  /**
   * Constructs a ConfigManager object.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   The config factory.
   */
  public function __construct(ConfigFactoryInterface $config_factory) {
    $this->configFactory = $config_factory;
  }

  /**
   * Gets the configuration object.
   *
   * @return \Drupal\Core\Config\Config
   *   The configuration object.
   */
  public function getConfig() {
    return $this->configFactory->get(self::CONFIG_NAME);
  }

  /**
   * Gets the editable configuration object.
   *
   * @return \Drupal\Core\Config\Config
   *   The editable configuration object.
   */
  public function getEditableConfig() {
    return $this->configFactory->getEditable(self::CONFIG_NAME);
  }

  /**
   * Gets the bot title.
   *
   * @return string
   *   The bot title.
   */
  public function getTitle() {
    return $this->getConfig()->get('title') ?: 'MeetMy.bot Clone';
  }

  /**
   * Gets the bot URL.
   *
   * @return string
   *   The bot URL.
   */
  public function getBotUrl() {
    return $this->getConfig()->get('bot_url') ?: '';
  }

  /**
   * Gets the display mode.
   *
   * @return string
   *   The display mode (modal or inline).
   */
  public function getDisplayMode() {
    return $this->getConfig()->get('display_mode') ?: 'modal';
  }

  /**
   * Gets the modal fullscreen setting.
   *
   * @return bool
   *   TRUE if modal should be fullscreen.
   */
  public function getModalFullscreen() {
    return (bool) $this->getConfig()->get('modal_fullscreen') ?: FALSE;
  }

  /**
   * Gets the complete width with unit.
   *
   * @return string
   *   The width with unit (e.g., "400px", "100%").
   */
  public function getWidth() {
    $value = $this->getConfig()->get('width_value') ?: '400';
    $unit = $this->getConfig()->get('width_unit') ?: 'px';
    return $value . $unit;
  }

  /**
   * Gets the complete height with unit.
   *
   * @return string
   *   The height with unit (e.g., "600px", "100%").
   */
  public function getHeight() {
    $value = $this->getConfig()->get('height_value') ?: '600';
    $unit = $this->getConfig()->get('height_unit') ?: 'px';
    return $value . $unit;
  }

  /**
   * Gets the width value.
   *
   * @return string
   *   The width value.
   */
  public function getWidthValue() {
    return $this->getConfig()->get('width_value') ?: '400';
  }

  /**
   * Gets the width unit.
   *
   * @return string
   *   The width unit.
   */
  public function getWidthUnit() {
    return $this->getConfig()->get('width_unit') ?: 'px';
  }

  /**
   * Gets the height value.
   *
   * @return string
   *   The height value.
   */
  public function getHeightValue() {
    return $this->getConfig()->get('height_value') ?: '600';
  }

  /**
   * Gets the height unit.
   *
   * @return string
   *   The height unit.
   */
  public function getHeightUnit() {
    return $this->getConfig()->get('height_unit') ?: 'px';
  }

  /**
   * Gets the preview video URL.
   *
   * @return string
   *   The preview video URL.
   */
  public function getPreviewVideoUrl() {
    return $this->getConfig()->get('preview_video_url') ?: '';
  }

  /**
   * Checks if the module is properly configured.
   *
   * @return bool
   *   TRUE if configured, FALSE otherwise.
   */
  public function isConfigured() {
    return !empty($this->getBotUrl());
  }

  /**
   * Gets all configuration as an array.
   *
   * @return array
   *   Array of configuration values.
   */
  public function getAllConfig() {
    return [
      'title' => $this->getTitle(),
      'bot_url' => $this->getBotUrl(),
      'display_mode' => $this->getDisplayMode(),
      'modal_fullscreen' => $this->getModalFullscreen(),
      'width' => $this->getWidth(),
      'height' => $this->getHeight(),
      'width_value' => $this->getWidthValue(),
      'width_unit' => $this->getWidthUnit(),
      'height_value' => $this->getHeightValue(),
      'height_unit' => $this->getHeightUnit(),
      'preview_video_url' => $this->getPreviewVideoUrl(),
    ];
  }

}